[Privoxy-commits] [privoxy] 12/19: chat(): Properly deal with inspected https requests

User Git git at git.privoxy.org
Thu Jun 11 08:29:16 CEST 2026


This is an automated email from the git hooks/post-receive script.

git pushed a commit to branch master
in repository privoxy.

commit 2a384a13d617bcb6ec673e73709e91cbb7bcc4bc
Author: Fabian Keil <fk at fabiankeil.de>
AuthorDate: Mon Jun 8 07:55:39 2026 +0200

    chat(): Properly deal with inspected https requests
    
    ... when treating the forwarding host as a webserver.
    
    Previously Privoxy would treat the client request as
    CONNECT request and forward it to the webserver which
    would then reject it due to the lack of an established
    TLS session.
---
 jcc.c | 8 +++++---
 1 file changed, 5 insertions(+), 3 deletions(-)

diff --git a/jcc.c b/jcc.c
index 45d24dc7..8a595001 100644
--- a/jcc.c
+++ b/jcc.c
@@ -4671,12 +4671,14 @@ static void chat(struct client_state *csp)
 #ifdef FEATURE_HTTPS_INSPECTION
       /*
        * Creating TLS connections with destination server or parent
        * proxy. If forwarding is enabled, we must send client request to
        * parent proxy and receive, parse and resend parent proxy answer.
        */
       if (http->ssl && !use_ssl_tunnel)
       {
-         if (fwd->forward_host != NULL)
+         if (fwd->forward_host != NULL && fwd->type != FORWARD_WEBSERVER)
          {
             char server_response[BUFFER_SIZE];
             int ret = 0;
@@ -4671,12 +4671,14 @@ static void chat(struct client_state *csp)
       /*
        * Creating TLS connections with destination server or parent
-       * proxy. If forwarding is enabled, we must send client request to
-       * parent proxy and receive, parse and resend parent proxy answer.
+       * proxy. If forwarding is enabled and we are not treating the
+       * forward host as webserver, we must send the client request to the
+       * parent proxy and receive, parse and resend the parent proxy
+       * answer.
        */
       if (http->ssl && !use_ssl_tunnel)

-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the Privoxy-commits mailing list